wasm_export

Function wasm_export 

pub(crate) fn wasm_export(attr: TokenStream, item: TokenStream) -> TokenStream
Applies #[wasm_bindgen] to an impl block or a free function, forwarding this macro’s arguments to it, and rewrites the methods marked #[wasm_only].