pub(crate) fn wasm_export(attr: TokenStream, item: TokenStream) -> TokenStreamExpand description
Applies #[wasm_bindgen] to an impl block or a free function, forwarding this macro’s
arguments to it, and rewrites the methods marked #[wasm_only].
pub(crate) fn wasm_export(attr: TokenStream, item: TokenStream) -> TokenStreamApplies #[wasm_bindgen] to an impl block or a free function, forwarding this macro’s
arguments to it, and rewrites the methods marked #[wasm_only].